        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 31 <br>2,3,4,5,6,8,10,12,13,16,17,18,21,22,23,25,28,29,30,32,34,36,37,38,39,40,41,43,46,47,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 15 <strong>control</strong><br>0,7,9,11,19,20,24,26,27,31,35,42,45,48,49';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260622 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 5 <br>1,14,15,33,44';}
}
